"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.esbuildPluginAliasPath = void 0;
const tslib_1 = require("tslib");
const normalize_options_1 = require("./normalize-options");
const typescript_1 = require("typescript");
const escape_namespace_1 = require("./escape-namespace");
// const debug = require('debug')('esbuild:alias-path');
const pluginName = 'esbuild:alias-path';
const esbuildPluginAliasPath = (options = {}) => {
    const { alias, skip, tsconfigPath, compilerOptions } = normalize_options_1.normalizeOption(options);
    if (skip) {
        return {
            name: pluginName,
            setup(build) { },
        };
    }
    const escapedNamespace = escape_namespace_1.escapeNamespace(Object.keys(alias));
    return {
        name: pluginName,
        setup(build) {
            // handle alias replacement
            build.onResolve({ filter: escapedNamespace }, ({ path: fromPath }) => {
                if (!alias[fromPath]) {
                    return null;
                }
                return {
                    path: alias[fromPath],
                };
            });
            // handle tsconfig paths mapping
            build.onResolve({ filter: /.*/ }, ({ path: filePath, importer }) => tslib_1.__awaiter(this, void 0, void 0, function* () {
                if (!compilerOptions.paths) {
                    return null;
                }
                const hasMatchingPath = Object.keys(compilerOptions.paths).some((path) => new RegExp(path.replace('*', '\\w*')).test(filePath));
                if (!hasMatchingPath) {
                    return null;
                }
                const { resolvedModule } = typescript_1.nodeModuleNameResolver(filePath, importer, compilerOptions, typescript_1.sys);
                const { resolvedFileName } = resolvedModule;
                if (!resolvedFileName || resolvedFileName.endsWith('.d.ts')) {
                    return null;
                }
                const resolved = typescript_1.sys.resolvePath(resolvedFileName);
                return {
                    path: resolved,
                };
            }));
        },
    };
};
exports.esbuildPluginAliasPath = esbuildPluginAliasPath;
//# sourceMappingURL=esbuild-plugin-alias-path.js.map